# vcokltfre/vcoutils

## This is a collection of utlities I have made or adapted for convenience.

### Current classes:

- `LeakyBucket` and `LeakyBucketManager` from `leakybucket.py`
- `Intents` from `intents.py`

### Current Decorators [discord.py](https://github.com/Rapptz/discord.py):

- `has_any_permissions(**perms)` and `has_any_guild_permissions(**perms)` from `extrachecks.py`

### Current Functions:

- `generate_id_solid()` and `generaie_id_split()` from `genid.py`